# Generated by roxygen2: do not edit by hand

export(AnthropicProcessor)
export(BaseAPIProcessor)
export(CacheManager)
export(DeepSeekProcessor)
export(GeminiProcessor)
export(GrokProcessor)
export(KimiProcessor)
export(MinimaxProcessor)
export(OpenAIProcessor)
export(OpenRouterProcessor)
export(QwenProcessor)
export(StepFunProcessor)
export(UnifiedLogger)
export(ZhipuProcessor)
export(annotate_cell_types)
export(compare_model_predictions)
export(configure_logger)
export(create_annotation_prompt)
export(create_reasoning_annotation_prompt)
export(get_api_key)
export(get_logger)
export(get_provider)
export(interactive_consensus_annotation)
export(list_custom_models)
export(list_custom_providers)
export(log_debug)
export(log_error)
export(log_info)
export(log_warn)
export(mllmcelltype_cache_dir)
export(mllmcelltype_clear_cache)
export(register_custom_model)
export(register_custom_provider)
importFrom(R6,R6Class)
importFrom(digest,digest)
importFrom(jsonlite,toJSON)
importFrom(stats,setNames)
importFrom(tools,R_user_dir)
importFrom(utils,head)
importFrom(utils,tail)
