# mLLMCelltype R Package

This directory contains additional resources for the mLLMCelltype R package.

## Package Structure

- `R/`: Contains R source code
- `man/`: Contains documentation files
- `tests/`: Contains test files
- `inst/`: Contains installed files (this directory)

## Usage

See the main README.md file in the project root directory for usage instructions.