% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_consensus.R
\name{extract_labeled_value}
\alias{extract_labeled_value}
\title{Extract numeric value from line containing a label}
\usage{
extract_labeled_value(lines, label_pattern)
}
\description{
Extract numeric value from line containing a label
}
\keyword{internal}
