% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_consensus.R
\name{check_consensus}
\alias{check_consensus}
\title{Check if consensus is reached among models}
\usage{
check_consensus(
  round_responses,
  api_keys = NULL,
  controversy_threshold = 2/3,
  entropy_threshold = 1,
  consensus_check_model = NULL,
  base_urls = NULL
)
}
\description{
Check if consensus is reached among models
}
\note{
This function uses create_consensus_check_prompt from prompt_templates.R
}
\keyword{internal}
