% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prompt_templates.R
\name{create_standardization_prompt}
\alias{create_standardization_prompt}
\title{Create prompt for standardizing cell type names}
\usage{
create_standardization_prompt(all_cell_types)
}
\description{
Create prompt for standardizing cell type names
}
\keyword{internal}
