% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_consensus.R
\name{calculate_simple_consensus}
\alias{calculate_simple_consensus}
\title{Calculate simple consensus without LLM}
\usage{
calculate_simple_consensus(round_responses)
}
\description{
Calculate simple consensus without LLM
}
\keyword{internal}
