% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prompt_templates.R
\name{create_discussion_prompt}
\alias{create_discussion_prompt}
\title{Create prompt for additional discussion rounds}
\usage{
create_discussion_prompt(
  cluster_id,
  cluster_genes,
  tissue_name,
  previous_rounds,
  round_number
)
}
\description{
Create prompt for additional discussion rounds
}
\keyword{internal}
