% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prompt_templates.R
\name{create_consensus_check_prompt}
\alias{create_consensus_check_prompt}
\title{Create prompt for checking consensus among model predictions}
\usage{
create_consensus_check_prompt(
  round_responses,
  controversy_threshold = 2/3,
  entropy_threshold = 1
)
}
\description{
Create prompt for checking consensus among model predictions
}
\keyword{internal}
