% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/zzz.R
\name{.onLoad}
\alias{.onLoad}
\title{Package load message}
\usage{
.onLoad(libname, pkgname)
}
\description{
Package load message
}
\keyword{internal}
