% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unified_logger.R
\name{logging_functions}
\alias{logging_functions}
\alias{log_debug}
\alias{log_info}
\alias{log_warn}
\alias{log_error}
\title{Convenience functions for logging}
\usage{
log_debug(message, context = NULL)

log_info(message, context = NULL)

log_warn(message, context = NULL)

log_error(message, context = NULL)
}
\arguments{
\item{message}{Log message string}

\item{context}{Optional context information (list or character)}
}
\value{
Invisible NULL
}
\description{
Convenience functions for logging
}
