% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare_model_predictions.R
\name{standardize_cell_type_names}
\alias{standardize_cell_type_names}
\title{Standardize cell type names using a language model}
\usage{
standardize_cell_type_names(
  predictions,
  models,
  api_keys,
  standardization_model = NULL,
  base_urls = NULL
)
}
\description{
This function takes predictions from multiple models and standardizes the cell type
nomenclature to ensure consistent naming across different models' outputs.
}
\details{
\enumerate{
\item With provider names as keys: \code{list("openai" = "sk-...", "anthropic" = "sk-ant-...", "openrouter" = "sk-or-...")}
\item With model names as keys: \code{list("gpt-5.5" = "sk-...", "claude-sonnet-4-6" = "sk-ant-...")}
}
}
\keyword{internal}
