% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/custom_model_manager.R
\name{process_custom}
\alias{process_custom}
\title{Process request using custom provider}
\usage{
process_custom(prompt, model, api_key, base_url = NULL)
}
\description{
Process request using custom provider
}
\keyword{internal}
