% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/custom_model_manager.R
\name{list_custom_providers}
\alias{list_custom_providers}
\title{Get list of registered custom providers}
\usage{
list_custom_providers()
}
\description{
Get list of registered custom providers
}
