% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache_utils.R
\name{mllmcelltype_clear_cache}
\alias{mllmcelltype_clear_cache}
\title{Clear mLLMCelltype cache}
\usage{
mllmcelltype_clear_cache(cache_dir = NULL)
}
\arguments{
\item{cache_dir}{Cache directory specification. NULL uses system default, "local" uses current dir, "temp" uses temp dir, or custom path}
}
\value{
Invisible NULL
}
\description{
Clear the mLLMCelltype cache
}
\examples{
\dontrun{
mllmcelltype_clear_cache()
mllmcelltype_clear_cache("local")
}
}
