% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unified_logger.R
\name{get_logger}
\alias{get_logger}
\title{Get the global logger instance}
\usage{
get_logger()
}
\description{
Get the global logger instance
}
