% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache_utils.R
\name{mllmcelltype_cache_dir}
\alias{mllmcelltype_cache_dir}
\title{Get mLLMCelltype cache location}
\usage{
mllmcelltype_cache_dir(cache_dir = NULL)
}
\arguments{
\item{cache_dir}{Cache directory specification. NULL uses system default, "local" uses current dir, "temp" uses temp dir, or custom path}
}
\value{
Invisible cache directory path
}
\description{
Display the cache directory location
}
\examples{
\dontrun{
mllmcelltype_cache_dir()
mllmcelltype_cache_dir("local")
}
}
